==> fstitch-annotate-0.3.0.tar.gz: fstitch-annotate-0.3.0/setup.py <==
#!/usr/bin/env python

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
#with open(path.join(here, 'README.md'), encoding='utf-8') as f:
#    long_description = f.read()

setup(name='fstitch-annotate',
      version='0.3.0',
      description='Provides additional annotation tools using FStitch segment data.',
      url='https://github.com/Dowell-Lab/FStitch',
      author='Margaret Gruca',
      author_email='margaret.gruca@colorado.edu',
      license='MIT',
      python_requires='>=3.6',
      classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Programming Language :: Python :: 3'
      ],
      
keywords='bioinformatics genomics eRNA enhancers regulation binding RNAPII polymerase GRO-seq PRO-seq motif transcription_factor',

    package_dir={'annotate' : 'annotate'},
    packages=['annotate'],

    install_requires=[
        'argparse',
        'datetime',
        'numpy',
        'pybedtools',
        'chartify',
        'pandas',
    ],

    entry_points={
        'console_scripts': [
            'bidir=annotate:bidir',
            'expand=annotate:expand',            
        ],
    },

    project_urls={
        'Bug Reports': 'https://github.com/Dowell-Lab/FStitch',
        'Source': 'https://github.com/Dowell-Lab/FStitch',
        'Human RefSeq': 'http://genome.ucsc.edu/cgi-bin/hgTables',
    },
)

==> fstitch-annotate-0.3.1.tar.gz: fstitch-annotate-0.3.1/setup.py <==
#!/usr/bin/env python

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
#with open(path.join(here, 'README.md'), encoding='utf-8') as f:
#    long_description = f.read()

setup(name='fstitch-annotate',
      version='0.3.1',
      description='Provides additional annotation tools using FStitch segment data.',
      url='https://github.com/Dowell-Lab/FStitch',
      author='Margaret Gruca',
      author_email='margaret.gruca@colorado.edu',
      license='MIT',
      python_requires='>=3.6',
      classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Programming Language :: Python :: 3'
      ],
      
keywords='bioinformatics genomics eRNA enhancers regulation binding RNAPII polymerase GRO-seq PRO-seq motif transcription_factor',

    package_dir={'annotate' : 'annotate'},
    packages=['annotate'],

    install_requires=[
        'argparse',
        'datetime',
        'numpy',
        'pybedtools',
        'chartify',
        'pandas',
    ],

    entry_points={
        'console_scripts': [
            'bidir=annotate:bidir',
            'expand=annotate:expand',            
        ],
    },

    project_urls={
        'Bug Reports': 'https://github.com/Dowell-Lab/FStitch/issues',
        'Source': 'https://github.com/Dowell-Lab/FStitch/annotate',
        'Human RefSeq': 'http://genome.ucsc.edu/cgi-bin/hgTables',
    },
)
